@@ -119,11 +119,11 @@ class ET_Describe(ET_Constructor):
 ##
 ########
 class ET_Configure(ET_Constructor):
-    def __init__(self, auth_stub, obj_type, props = None):        
+    def __init__(self, auth_stub, obj_type, props = None, update = False):        
         auth_stub.refresh_token()
 
         ws_configureRequest = auth_stub.soap_client.factory.create('ConfigureRequestMsg')
-        ws_configureRequest.Action = 'create'        
+        ws_configureRequest.Action = 'create' if update is False else 'update'
         ws_configureRequest.Configurations = {'Configuration': self.parse_props_into_ws_object(auth_stub, obj_type, props)}
 
         response = auth_stub.soap_client.service.Configure(None, ws_configureRequest)        
